*** Macros
	drop _all
	clear
	if "`c(username)'" == "dwadhwa"{
		global path "C:/Users/dwadhwa/Dropbox/Charts/3 Doing Business/dbrank"
	}
	if "`c(username)'" == "Justin" {
		global path "/Users/Justin/Dropbox/Charts/3 Doing Business/dbrank"
	}	
	
*** DB historical series, downloaded 1/14/18 from http://www.doingbusiness.org/~/media/WBG/DoingBusiness/Documents/Data/DB18-Historical-data-complete-data-with-DTFs.xlsx
	import excel "$path/input/DB18-Historical-data-complete-data-with-DTFs.xlsx", sheet("All Data") firstrow

	rename Ease F
	rename Start K 
	rename Deal AA
	rename Gettingelect AR
	rename Regist BL
	rename Gettingcred CE 
	rename Protect CT 
	rename Payingtax DO 
	rename Trading EJ 
	rename Enforcing FO 
	rename Resolv GN
	
	tokenize F J K Z AA AQ AR BK BL CD CE CS CT DN DO EI EJ FN FO GM GN HA
	local a = 1
	foreach pre in Ease Start Construct Power Land Credit Invest Tax Trade Contract Bankrupt{
		local b = `a' + 1
		
		foreach var of varlist ``a'' - ``b''{
			local temp = `var'[_n==1]
			label variable `var' "`temp'"
			rename `var' `pre'_`var' 
		}
		
		local a = `a' + 2
	}
	foreach var of varlist A - E{
		local temp = `var'[_n==1]
		label variable `var' "`temp'"
		local temp = subinstr("`temp'"," ","",.)
		rename `var' `temp' 
	}

	
*** Easier if variable names are numbered within sub-indices
	foreach pre in Ease Start Construct Power Land Credit Invest Tax Trade Contract Bankrupt{
		local n = 1
		foreach var of varlist `pre'_*{
			if `n'<10{
				rename `var' `var'0`n'
			}
			else{
				rename `var' `var'`n'
			}
			local ++n
		}
	}
	drop if _n==1
	rename DBYear year
	destring year Ease* Start* Construct* Power* Land* Credit* Invest* Tax* Trade* Contract* Bankrupt*, force replace
	encode Countrycode, g(ccode)
	sort ccode year
	tsset ccode year
	order Countrycode ccode
	
*** Drop cities not used in rankings
	drop if Countrycode == "RUS_Sai"
	drop if Countrycode == "RUS" & year>=2014
	replace Countrycode = "RUS" if Countrycode=="RUSS"
	
	drop if Countrycode == "USA_Losa"
	drop if Countrycode == "USA" & year>=2014
	replace Countrycode = "USA" if Countrycode=="US"
	
	drop if Countrycode == "BGD_Chit"
	drop if Countrycode == "BGD" & year>=2014
	replace Countrycode = "BGD" if Countrycode=="BANG"

	drop if Countrycode == "BRA_Rio"
	drop if Countrycode == "BRA" & year>=2014
	replace Countrycode = "BRA" if Countrycode=="BRAZ"

	drop if Countrycode == "CHN_Beij"
	drop if Countrycode == "CHN" & year>=2014
	replace Countrycode = "CHN" if Countrycode=="CHIN"

	drop if Countrycode == "IND_Delh"
	drop if Countrycode == "IND" & year>=2014
	replace Countrycode = "IND" if Countrycode=="INDI"

	drop if Countrycode == "IDN_Sura"
	drop if Countrycode == "IDN" & year>=2014
	replace Countrycode = "IDN" if Countrycode=="INDO"

	drop if Countrycode == "MEX_Mont"
	drop if Countrycode == "MEX" & year>=2014
	replace Countrycode = "MEX" if Countrycode=="MEXI"

	drop if Countrycode == "JPN_Osak"
	drop if Countrycode == "JPN" & year>=2014
	replace Countrycode = "JPN" if Countrycode=="JAP"

	drop if Countrycode == "NGA_Kano"
	drop if Countrycode == "NGA" & year>=2014
	replace Countrycode = "NGA" if Countrycode=="NIGE"

	drop if Countrycode == "PAK_Laho"
	drop if Countrycode == "PAK" & year>=2014
	replace Countrycode = "PAK" if Countrycode=="PAKI"

	save "$path/output/db_all.dta", replace
	
	mmerge Countrycode year using "$path/output/dbranking.dta", umatch(isocode year)
	replace rank = Ease_F01 if year==2018
	save "$path/output/db_all.dta", replace

		duplicates drop ccode year, force
	sort ccode year
	tsset ccode year

**************************
*** REPLICATE RANKINGS ***
**************************

*** Create a series of current/contemporary DTF scores
*** NB: overlaps are due to back-casting, so use earlier series as reflected in contemporaneous DB report
	gen lag = .
	gen oldlag = .
	gen Ease_06 = 1
	foreach pre in Ease Start Construct Power Land Credit Invest Tax Trade Contract Bankrupt{
		gen `pre'_DTF = .
		forval n = 2/5{
			local o = `n' + 1
			
			replace lag = l.`pre'_DTF
			reg		`pre'_*0`n' 
			local 	v = e(depvar)
			reg 	`pre'_*0`o'
			local 	w = e(depvar)
			replace oldlag = l.`w'
			
			replace `pre'_DTF = `v' if `pre'_DTF==.
			replace `pre'_DTF = `v' if `v'!=. & `w'!=. & lag==. & oldlag!=. & year!=2018
		}
	}
	egen DTF_total = rmean(*_DTF)
	bysort year: egen myrank = rank(Ease_DTF), field
	bysort year: egen mymyrank = rank(DTF_total), field	


****************************
*** HOLD METHOD CONSTANT ***
****************************

	foreach pre in Ease Start Construct Power Land Credit Invest Tax Trade Contract Bankrupt{
		foreach var of varlist `pre'*{
			sum `var' if year==2006
			if r(N)==0{
				drop `var' 
			}
		}
	}
	egen Start_DTF06 		= rmean(Start_T10 - Start_Z16)
	egen Construct_DTF06 	= rmean(Construct_AN14 - Construct_AP16)
	egen Land_DTF06 		= rmean(Land_BZ15 - Land_CB17)
	egen Credit_DTF06 		= rmean(Credit_CP12 Credit_CQ13)
	egen Invest_DTF06 		= rmean(Invest_DH15 - Invest_DJ17)
	egen Tax_DTF06 			= rmean(Tax_EC15 - Tax_EE17)
	egen Trade_DTF06 		= rmean(Trade_FA18 - Trade_FF23)
	egen Contract_DTF06 	= rmean(Contract_GI21 - Contract_GK23)
	gen  Bankrupt_DTF06 	= Bankrupt_GZ13
	egen DTF06_total		= rmean(Start_DTF06 - Bankrupt_DTF06)
	
*** Fixed sample
	keep if year>=2006
//exit

	duplicates tag Countrycode, g(dup)
	keep if dup==12

	bysort year: egen fixedrank = rank(DTF06_total), field
	save "$path/output/db.dta", replace

	
