library(ggplot2)
library(readxl)
library(plyr)
library(dplyr)
library(countrycode)
library(foreign)
library(reshape2)
library(readstata13)
library(RColorBrewer)
library(scales)
library(doBy)
library(grid)
library(gridExtra)
library(ggrepel)
library(stringr)
library(fmsb)
library(Cairo)
library(epanetReader)
library(RCurl)
library(bitops)
library(ggthemes)
library(reshape)

##### Set Directory #####
setwd("C:/Users/dwadhwa/Dropbox/Charts/3 Doing Business/dbrank/output")

ds <- read.dta13("db.dta")

theme1 <- theme_bw() + 
  theme(plot.background = element_rect(fill ="#f3f3f3"), panel.background = element_rect(fill = "#f3f3f3")) +
  theme(panel.border= element_blank()) +
  theme(title = element_text(size = 18),
        axis.title = element_text(colour="black", size = 12)) +
  theme(legend.title = element_blank()) +
  theme(axis.line.x = element_line(colour="black", size = 1),
        axis.line.y = element_blank(),
        axis.text.x = element_text(colour="black", size = 10),
        axis.text.y = element_text(colour = "black"),
        axis.ticks.x = element_line(colour="black"),
        axis.ticks.y = element_blank()) +
  theme(legend.position = "bottom", legend.direction="vertical",
        legend.key = element_rect(size = 10),
        legend.key.size = unit(1.75, "lines"),
        legend.text.align = 0) +
  theme(legend.text=element_text(size=12))

df <- subset(ds,Economy == "Chile")

c <- ggplot(df) + 
  geom_rect(data=NULL,aes(xmin=2006, xmax=2010,ymin=-Inf,ymax=Inf),
            fill= alpha("white", 0.3)) +
  geom_rect(data=NULL,aes(xmin=2014, xmax=Inf,ymin=-Inf,ymax=Inf),
            fill= "white") +
  geom_line(aes(x = year, y = rank, col = "Ranking published by Doing Business"), size = 1.5) +
  geom_line(aes(x = year, y = fixedrank, col = "Ranking using a fixed set of indicators and fixed sample of countries"), size = 1.5) +
  geom_point(aes(x = year, y = rank, col = "Ranking published by Doing Business"), size = 3) +
  geom_point(aes(x = year, y = fixedrank, col = "Ranking using a fixed set of indicators and fixed sample of countries"), size = 3) +
  geom_text(data=subset(df, ((rank < 35 | rank > 48) & year > 2008) | year == 2006 | year == 2018),
            aes(x = year, y = rank, label=rank), size=5, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#f95602") +
  geom_text(data=subset(df, ((fixedrank <= 30 | fixedrank > 38) & year > 2008) | year == 2006 | year == 2018),
            aes(x = year, y = fixedrank, label=fixedrank), size=5, position=position_dodge(width=0.9), vjust=-1.1, 
            color =  "#006b77") +
  theme1 +
  labs(title = "Chile's 'Doing Business' rank",
       subtitle = "Changes to the World Bank methodology penalized Chile under Socialist governments,\neven though the underlying indicators barely moved\n",
       x="",
       y="") +
  scale_colour_manual(labels=c("Ranking published by Doing Business",
                             "Ranking using a fixed set of indicators and fixed sample of countries"),
                    values=c("#f95602", "#006b77")) +
  scale_x_continuous(breaks = c(2006, 2010, 2014)) +
  scale_y_continuous(breaks = c(30, 40, 50), limits = c(24, 58)) +
  scale_y_reverse() +
  geom_segment(aes(x=2006, xend=2006, y=-Inf, yend=58), linetype= "dotted") +
  geom_segment(aes(x=2010, xend=2010, y=-Inf, yend=58), linetype= "dotted") +
  geom_segment(aes(x=2014, xend=2014, y=-Inf, yend=58), linetype= "dotted") +
  annotate("text", x = 2008, y = 24, label = "Bachelet presidency") +
  annotate("text", x = 2012, y = 24, label = "Piera presidency") +
  annotate("text", x = 2016, y = 24, label = "Bachelet presidency")

  c
  
######## Spark lines ########
  
#  ds$regioncode <- NULL
#  ds$regioncode[ds$Region == "East Asia & Pacific"] <- "EAP"
#  ds$regioncode[ds$Region == "Europe & Central Asia"] <- "ECA"
#  ds$regioncode[ds$Region == "High income: OECD"] <- "OECD"
#  ds$regioncode[ds$Region == "Latin America & Caribbean"] <- "LATAM"
#  ds$regioncode[ds$Region == "Middle East & North Africa"] <- "MENA"
#  ds$regioncode[ds$Region == "South Asia"] <- "SA"
#  ds$regioncode[ds$Region == "Sub-Saharan Africa"] <- "SSA"
  
  spark <- function(ds, a, x, y, z) {
    
    ds$Economy <- str_wrap(ds$Economy, width = 10)
    
    mins <- group_by(ds, Countrycode) %>% slice(which.min(rank))
    maxs <- group_by(ds, Countrycode) %>% slice(which.max(rank))
    ends <- group_by(ds, Countrycode) %>% filter(year == max(year))
    
    mins2 <- group_by(ds, Countrycode) %>% slice(which.min(fixedrank))
    maxs2 <- group_by(ds, Countrycode) %>% slice(which.max(fixedrank))
    
    quarts <- ds %>% group_by(Countrycode) %>%
      summarize(quart1 = quantile(rank, 0.25, na.rm = T),
                quart2 = quantile(rank, 0.75, na.rm = T),
                quart3 = quantile(fixedrank, 0.25, na.rm = T),
                quart4 = quantile(fixedrank, 0.75, na.rm = T)) %>%
      right_join(ds)
    
    range <- maxs$rank - mins$rank
    range2 <- maxs2$fixedrank - mins2$fixedrank
    
    ggplot(ds) + 
      facet_grid(Countrycode ~ ., scales = "fixed") + 
      geom_ribbon(data = quarts, aes(x=year, y=rank, ymin = 0, ymax = 189), fill = 'white') +
      geom_line(aes(x=year, y=rank), size=0.3, color = "#f95602") +
      geom_line(aes(x=year, y=fixedrank), size=0.3, color = "#006b77") +
      geom_point(data = mins, aes(x=year, y=rank), col = '#f95602') +
      geom_point(data = maxs, aes(x=year, y=rank), col = '#f95602') +
      geom_point(data = mins2, aes(x=year, y=fixedrank), col = '#006b77') +
      geom_point(data = maxs2, aes(x=year, y=fixedrank), col = '#006b77') +
      geom_text(data = mins, aes(x=year, y=rank, label = rank), vjust = a, hjust = y, col = '#f95602') +
      geom_text(data = maxs, aes(x=year, y=rank, label = rank), vjust = x, hjust = y, col = '#f95602') +
      geom_text(data = mins2, aes(x=year, y=fixedrank, label = fixedrank), vjust = a, hjust = z , col = '#006b77') +
      geom_text(data = maxs2, aes(x=year, y=fixedrank, label = fixedrank), vjust = x, hjust = z, col = '#006b77') +
      geom_text(data = ends, aes(x=year, y=95, label = Economy), hjust = 0, nudge_x = 1) +
      expand_limits(x = 2020, y = c(-10, 193)) +
      scale_x_continuous(breaks = c(2006, 2010, 2014, 2018)) +
      scale_y_reverse() +
      theme_tufte(base_size = 15, base_family = "Helvetica") +
      theme(axis.title=element_blank(), axis.text.y = element_blank(), 
            axis.ticks = element_blank(), strip.text = element_blank()) +
      theme(plot.margin = unit(c(1, 1, 1, 1), "lines")) + 
      theme(plot.background = element_rect(fill ="#f3f3f3"))
      
    
  }
  
  dseap <- subset(ds, Region == "East Asia & Pacific")
  pdf("eap.pdf", height=23, width=8) 
  eap <- spark(dseap, 1.5, 1.5, 1, -0.5) 
  eap
  dev.off()
  
  dseca <- subset(ds, Region == "Europe & Central Asia")
  pdf("eca.pdf", height=20, width=8)
  eca <- spark(dseca, 1.5, 1.5, 1, -0.5)
  eca
  dev.off()
  
  dsoecd <- subset(ds, Region == "High income: OECD")
  pdf("oecd.pdf", height=32, width=8)
  oecd <- spark(dsoecd, 1.5, 1.5, 1, -0.5)
  oecd
  dev.off()
  
  dslat <- subset(ds, Region == "Latin America & Caribbean")
  pdf("lat.pdf", height=30, width=8)
  lat <- spark(dslat, -0.5, -0.5, 1, -0.5)
  lat
  dev.off()
  
  dsmena <- subset(ds, Region == "Middle East & North Africa")
  pdf("mena.pdf", height=16, width=8)
  mena <- spark(dsmena, 0.75, 0.75, 1, -0.5)
  mena
  dev.off()
  
  dssa <- subset(ds, Region == "South Asia")
  pdf("sa.pdf", height=8, width=8)
  sa <- spark(dssa, -0.8, -0.8, 1, -0.5)
  sa
  dev.off()
  
  dsssa <- subset(ds, Region == "Sub-Saharan Africa")
  pdf("ssa.pdf", height=44, width=8)
  ssa <- spark(dsssa, -0.2, -0.7, 1, -0.25)
  ssa
  dev.off()
  
